@@ -36,9 +36,12 @@ AIRFLOW_V_3_0_PLUS = get_base_airflow_version_tuple() >= (3, 0, 0)
 AIRFLOW_V_3_1_PLUS = get_base_airflow_version_tuple() >= (3, 1, 0)
 
 if AIRFLOW_V_3_1_PLUS:
-    from airflow.sdk import BaseOperator
+    from airflow.models.xcom import XCOM_RETURN_KEY
+    from airflow.sdk import BaseHook, BaseOperator
 else:
-    from airflow.models import BaseOperator  # type: ignore[no-redef]
+    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+    from airflow.models import BaseOperator
+    from airflow.utils.xcom import XCOM_RETURN_KEY  # type: ignore[no-redef]
 
 if AIRFLOW_V_3_0_PLUS:
     from airflow.sdk import BaseSensorOperator
@@ -54,9 +57,11 @@ else:
 __all__ = [
     "AIRFLOW_V_3_0_PLUS",
     "AIRFLOW_V_3_1_PLUS",
+    "BaseHook",
     "BaseOperator",
     "BaseSensorOperator",
     "DecoratedOperator",
     "TaskDecorator",
     "task_decorator_factory",
+    "XCOM_RETURN_KEY",
 ]
